@@ -25,7 +25,7 @@ locale.textdomain('kuwo')
 _ = gettext.gettext
 
 APPNAME = _('KW Player')
-VERSION = '3.0'
+VERSION = '3.1'
 HOMEPAGE = 'https://github.com/LiuLang/kwplayer'
 AUTHORS = ['LiuLang <gsushzhsosgsu@gmail.com>',]
 DESCRIPTION = _('A simple music player which can get songs from kuwo.cn')
@@ -70,12 +70,12 @@ _default_conf = {
 def check_first():
     if not os.path.exists(CONF_DIR):
         try:
-            os.mkdir(CONF_DIR)
+            os.makedirs(CONF_DIR)
         except Exception as e:
             print(e)
     if not os.path.exists(CACHE_DIR):
         try:
-            os.mkdir(CACHE_DIR)
+            os.makedirs(CACHE_DIR)
             os.mkdir(IMG_DIR)
             os.mkdir(IMG_LARGE_DIR)
             os.mkdir(_default_conf['song-dir'])
